@@ -1,7 +1,7 @@
 #
 # This file is part of Dist-Zilla-PluginBundle-RSRCHBOY
 #
-# This software is Copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011 by Chris Weyl.
+# This software is Copyright (c) 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by Chris Weyl.
 #
 # This is free software, licensed under:
 #
@@ -9,13 +9,13 @@
 #
 package Dist::Zilla::PluginBundle::RSRCHBOY;
 our $AUTHORITY = 'cpan:RSRCHBOY';
-# git description: 0.074-1-g956fa42
-$Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.075';
+# git description: 0.074-8-g42133a5
+$Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.076';
 
 # ABSTRACT: Zilla your distributions like RSRCHBOY!
 
 use utf8;
-use v5.20;
+use v5.18;
 
 use Moose;
 use namespace::autoclean;
@@ -35,7 +35,7 @@ with
 use Config::MVP::Slicer 0.302;
 use Path::Class;
 
-has github_user     => (is => 'lazy', isa => 'Str', builder => sub { 'RsrchBoy' });
+has github_user     => (is => 'lazy', isa => 'Str', builder => sub { 'rsrchboy' });
 has set_github_user => (is => 'lazy', isa => 'Str', builder => sub { 1 }         );
 
 # FIXME this next section is kinda... ugly
@@ -185,7 +185,7 @@ sub author_tests {
             Test::Pod::LinkCheck
             RunExtraTests
         },
-        [ 'Test::MinimumVersion' => { max_target_perl => '5.008008' } ],
+        [ 'Test::MinimumVersion' => { max_target_perl => '5.020000' } ],
     );
 }
 
@@ -195,7 +195,7 @@ sub meta_provider_plugins {
 
     my @plugins = (
         [ Authority => { authority => 'cpan:RSRCHBOY' } ],
-        qw{ MetaConfig MetaJSON MetaYAML },
+        qw{ MetaConfig MetaJSON },
         [ MetaNoIndex => { directory => [ qw{ corpus t } ] } ],
         'MetaProvides::Package',
 
@@ -360,7 +360,7 @@ Dist::Zilla::PluginBundle::RSRCHBOY - Zilla your distributions like RSRCHBOY!
 
 =head1 VERSION
 
-This document describes version 0.075 of Dist::Zilla::PluginBundle::RSRCHBOY - released May 08, 2017 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
+This document describes version 0.076 of Dist::Zilla::PluginBundle::RSRCHBOY - released March 05, 2018 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
 
 =head1 SYNOPSIS
 
@@ -466,7 +466,7 @@ L<Config::MVP::Slicer|Config::MVP::Slicer>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/RsrchBoy/dist-zilla-pluginbundle-rsrchboy/issues>
+L<https://github.com/rsrchboy/dist-zilla-pluginbundle-rsrchboy/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -494,7 +494,7 @@ Sergey Romanov <complefor@rambler.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011 by Chris Weyl.
+This software is Copyright (c) 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by Chris Weyl.
 
 This is free software, licensed under:
 
